@@ -8,7 +8,7 @@ function(column.names, inside=FALSE) {
     all.combn <- sapply(1:ncolumns, function(idx) as.matrix(combn(ncolumns, idx)), simplify = FALSE)
     for (j in 1:length(all.combn)) {
         idk <- all.combn[[j]]
-        tt <- as.matrix(expand.grid(rep(list(c(0, 1)), nrow(idk)))[, nrow(idk):1])
+        tt <- createMatrix(nrow(idk))
         for (k in 1:ncol(idk)) {
             end.row <- start.row + nrow(tt) - 1
             return.matrix[start.row:end.row, idk[, k]] <- tt
