@@ -41,10 +41,22 @@ function(mydata, outcome = "", conditions = c(""), inside = FALSE,
         colnames(mydata)[ncol(mydata)] <- outcm.name
         }
     
-    tt <- as.matrix(expand.grid(rep(list(c(0,1)), no.conditions))[, no.conditions:1])
+    
+    
+    # the "old" way, which at the time it was 10 times faster than the initial code
+    # tt <- as.matrix(expand.grid(rep(list(c(0,1)), no.conditions))[, no.conditions:1])
+    
+    # the new way, which is 5.5 times faster than expand.grid :))
+    tt <- createMatrix(no.conditions)
+    
+    
     tt <- cbind(tt, NA)
     colnames(tt) <- colnames(mydata)
     
+        
+    
+    
+    
      # the three lines below transform the binary lines from mydata
      # into corresponding row numbers from the truth table
     line.tt <- mydata[, 1]
